This is a C wrapper to Rmumps::set_permutation(permutation) method. Available in R too.
In C++ code can be used as rmumps::Rmumps__set_permutation(pm, permutation)
Rmumps__set_permutation(pm, permutation)pointer of type XPtr<Rmumps>, object having sparse matrix permuted according to a chosen method.
integer one of predefined constants (cf. RMUMPS_PERM). Setting a new permutation invalidates current symbolic and numeric matrix decompositions.